==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/cs/Filter.js <==
({
	"clearFilterDialogTitle": "Vymazat filtr",
	"filterDefDialogTitle": "Filtr",
	"ruleTitleTemplate": "Pravidlo ${0}",
	
	"conditionEqual": "rovná se",
	"conditionNotEqual": "nerovná se",
	"conditionLess": "méně než",
	"conditionLessEqual": "méně nebo rovno",
	"conditionLarger": "více než",
	"conditionLargerEqual": "více nebo rovno",
	"conditionContains": "obsahuje",
	"conditionIs": "je",
	"conditionStartsWith": "začíná",
	"conditionEndWith": "končí",
	"conditionNotContain": "neobsahuje",
	"conditionIsNot": "není",
	"conditionNotStartWith": "nezačíná",
	"conditionNotEndWith": "nekončí",
	"conditionBefore": "před",
	"conditionAfter": "po",
	"conditionRange": "rozsah",
	"conditionIsEmpty": "je prázdné",
	
	"all": "vše",
	"any": "jakékoli",
	"relationAll": "všechna pravidla",
	"waiRelAll": "Porovnat všechna tato pravidla:",
	"relationAny": "jakákoli pravidla",
	"waiRelAny": "Porovnat jakákoli z těchto pravidel:",
	"relationMsgFront": "Shoda",
	"relationMsgTail": "",
	"and": "a",
	"or": "nebo",
	
	"addRuleButton": "Přidat pravidlo",
	"waiAddRuleButton": "Přidat nové pravidlo",
	"removeRuleButton": "Odebrat pravidlo",
	"waiRemoveRuleButtonTemplate": "Odebrat pravidlo ${0}",
	
	"cancelButton": "Storno",
	"waiCancelButton": "Zrušit toto dialogové okno",
	"clearButton": "Vymazat",
	"waiClearButton": "Vymazat filtr",
	"filterButton": "Filtr",
	"waiFilterButton": "Odeslat filtr",
	
	"columnSelectLabel": "Sloupec",
	"waiColumnSelectTemplate": "Sloupec pro pravidlo ${0}",
	"conditionSelectLabel": "Podmínka",
	"waiConditionSelectTemplate": "Podmínka pro pravidlo ${0}",
	"valueBoxLabel": "Hodnota",
	"waiValueBoxTemplate": "Zadejte hodnotu do filtru pro pravidlo ${0}",
	
	"rangeTo": "do",
	"rangeTemplate": "z ${0} do ${1}",
	
	"statusTipHeaderColumn": "Sloupec",
	"statusTipHeaderCondition": "Pravidla",
	"statusTipTitle": "Panel filtrování",
	"statusTipMsg": "Klepněte zde na panel filtrování, abyste filtrovali hodnoty v ${0}.",
	"anycolumn": "jakýkoli sloupec",
	"statusTipTitleNoFilter": "Panel filtrování",
	"statusTipTitleHasFilter": "Filtr",
	"statusTipRelPre": "Shoda",
	"statusTipRelPost": "pravidla.",
	
	"defaultItemsName": "položek",
	"filterBarMsgHasFilterTemplate": "${0} z ${1} ${2} zobrazeno.",
	"filterBarMsgNoFilterTemplate": "Není použitý žádný filtr",
	
	"filterBarDefButton": "Definovat filtr",
	"waiFilterBarDefButton": "Filtrovat tabulku",
	"a11yFilterBarDefButton": "Filtrovat...",
	"filterBarClearButton": "Vymazat filtr",
	"waiFilterBarClearButton": "Vymazat filtr",
	"closeFilterBarBtn": "Zavřít panel filtrování",
	
	"clearFilterMsg": "Tímto se odebere filtr a zobrazí všechny dostupné záznamy.",
	"anyColumnOption": "Jakýkoli sloupec",
	
	"trueLabel": "Pravda",
	"falseLabel": "Nepravda"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/cs/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "Vymazat filtr",
	"filterDefDialogTitle": "Filtr",
	"ruleTitleTemplate": "Pravidlo ${0}",
	
	"conditionEqual": "rovná se",
	"conditionNotEqual": "nerovná se",
	"conditionLess": "méně než",
	"conditionLessEqual": "méně nebo rovno",
	"conditionLarger": "více než",
	"conditionLargerEqual": "více nebo rovno",
	"conditionContains": "obsahuje",
	"conditionIs": "je",
	"conditionStartsWith": "začíná",
	"conditionEndWith": "končí",
	"conditionNotContain": "neobsahuje",
	"conditionIsNot": "není",
	"conditionNotStartWith": "nezačíná",
	"conditionNotEndWith": "nekončí",
	"conditionBefore": "před",
	"conditionAfter": "po",
	"conditionRange": "rozsah",
	"conditionIsEmpty": "je prázdné",
	
	"all": "vše",
	"any": "jakékoli",
	"relationAll": "všechna pravidla",
	"waiRelAll": "Porovnat všechna tato pravidla:",
	"relationAny": "jakákoli pravidla",
	"waiRelAny": "Porovnat jakákoli z těchto pravidel:",
	"relationMsgFront": "Shoda",
	"relationMsgTail": "",
	"and": "a",
	"or": "nebo",
	
	"addRuleButton": "Přidat pravidlo",
	"waiAddRuleButton": "Přidat nové pravidlo",
	"removeRuleButton": "Odebrat pravidlo",
	"waiRemoveRuleButtonTemplate": "Odebrat pravidlo ${0}",
	
	"cancelButton": "Storno",
	"waiCancelButton": "Zrušit toto dialogové okno",
	"clearButton": "Vymazat",
	"waiClearButton": "Vymazat filtr",
	"filterButton": "Filtr",
	"waiFilterButton": "Odeslat filtr",
	
	"columnSelectLabel": "Sloupec",
	"waiColumnSelectTemplate": "Sloupec pro pravidlo ${0}",
	"conditionSelectLabel": "Podmínka",
	"waiConditionSelectTemplate": "Podmínka pro pravidlo ${0}",
	"valueBoxLabel": "Hodnota",
	"waiValueBoxTemplate": "Zadejte hodnotu do filtru pro pravidlo ${0}",
	
	"rangeTo": "do",
	"rangeTemplate": "z ${0} do ${1}",
	
	"statusTipHeaderColumn": "Sloupec",
	"statusTipHeaderCondition": "Pravidla",
	"statusTipTitle": "Panel filtrování",
	"statusTipMsg": "Klepněte zde na panel filtrování, abyste filtrovali hodnoty v ${0}.",
	"anycolumn": "jakýkoli sloupec",
	"statusTipTitleNoFilter": "Panel filtrování",
	"statusTipTitleHasFilter": "Filtr",
	"statusTipRelAny": "Vyhovovat libovolnému pravidlu",
	"statusTipRelAll": "Vyhovovat všem pravidlům",
	
	"defaultItemsName": "položek",
	"filterBarMsgHasFilterTemplate": "${0} z ${1} ${2} zobrazeno.",
	"filterBarMsgNoFilterTemplate": "Není použitý žádný filtr",
	
	"filterBarDefButton": "Definovat filtr",
	"waiFilterBarDefButton": "Filtrovat tabulku",
	"a11yFilterBarDefButton": "Filtrovat...",
	"filterBarClearButton": "Vymazat filtr",
	"waiFilterBarClearButton": "Vymazat filtr",
	"closeFilterBarBtn": "Zavřít panel filtrování",
	
	"clearFilterMsg": "Tímto se odebere filtr a zobrazí všechny dostupné záznamy.",
	"anyColumnOption": "Jakýkoli sloupec",
	
	"trueLabel": "Pravda",
	"falseLabel": "Nepravda"
})
//end v1.x content
);
